==> react-embed-3.3.0.tgz: package/README.md <==
<div align="center">
  <h1>
    react-embed
  </h1>
</div>

<div align="center">
  <pre>import Embed from 'react-embed';</pre>
</div>

<br />
<br />

<div align="center">
  <pre>&#x3C;Embed url=&#x27;https://www.youtube.com/watch?v=soICQ3B2kEk&#x27; /&#x3E;</pre>
  <img src="https://user-images.githubusercontent.com/9773803/53292118-473ced80-37be-11e9-8cba-1380e111ef33.png">
</div>

<br />
<br />

<div align="center">
  <pre>&#x3C;Embed url=&#x27;https://soundcloud.com/s1sh1/kravts-glupyy-molodoy-na-meli&#x27; /&#x3E;</pre>
  <img src="https://user-images.githubusercontent.com/9773803/53292083-933b6280-37bd-11e9-8762-3a47b0a3bba3.png">
</div>

<br />
<br />

<div align="center">
  <pre>&#x3C;Embed url=&#x27;https://twitter.com/hercuppacoffee/status/911958476678561792&#x27; /&#x3E;</pre>
  <img src="https://user-images.githubusercontent.com/9773803/53292170-e6fa7b80-37be-11e9-87ab-8b16ab696412.png">
</div>

<br />
<br />

<div align="center">
  <h2>
    Dark mode
  </h2>
</div>

<div align="center">
  <pre>&#x3C;Embed isDark url=&#x27;https://twitter.com/hercuppacoffee/status/911958476678561792&#x27; /&#x3E;</pre>
  <img src="https://user-images.githubusercontent.com/9773803/80277289-44a19500-86ee-11ea-8dc7-0d12888cbc2d.png">
</div>

<div align="center">
  <h2>
    Responsive
  </h2>
</div>

<div align="center">
  <pre>&#x3C;Embed url=&#x27;...&#x27; /&#x3E;</pre>
  <img src="https://user-images.githubusercontent.com/9773803/80277360-b548b180-86ee-11ea-9b25-3eaa10027ca6.png">
</div>

<div align="center">
  <pre>&#x3C;Embed width={300} url=&#x27;...&#x27; /&#x3E;</pre>
  <img src="https://user-images.githubusercontent.com/9773803/80277394-e923d700-86ee-11ea-80da-9ff0aaab9d8f.png">
</div>

<br />
<br />

<div align="center">
  <h2>
    Supported
  </h2>
</div>

<br />

- DailyMotion
- Facebook Video
- Figma
- Gfycat
- Gist
- Google Maps
- imgur
- Instagram
- JSFiddle
- MixCloud
- Replit
- SoundCloud
- Twitch Channel
- Twitch Video
- Twitter Tweet
- Vimeo
- YouTube
- Audio files: `.mp3`, `.wav`, `.weba`, `.aac`, `.oga`, `.m4a`, `.mp4`, `.ogg`, `.opus`, `.ts`, `.wma`, `.mp4a`, `.mpga`, `.mp2`, `.mp2a`, `.m2a`, `.m3a`,
- Video files: `.spx`, `.mp4`, `.og`, `.ogv`, `.webm`, `.mov`, `.m4v`, `.m3u8`, `.mpd`

==> react-embed-3.3.3.tgz: package/README.md <==
<div align="center">
  <h1>
    react-embed
  </h1>
</div>

<div align="center">
  <pre>import Embed from 'react-embed';</pre>
</div>

<br />
<br />

<div align="center">
  <pre>&#x3C;Embed url=&#x27;https://www.youtube.com/watch?v=soICQ3B2kEk&#x27; /&#x3E;</pre>
  <img src="https://user-images.githubusercontent.com/9773803/53292118-473ced80-37be-11e9-8cba-1380e111ef33.png">
</div>

<br />
<br />

<div align="center">
  <pre>&#x3C;Embed url=&#x27;https://soundcloud.com/s1sh1/kravts-glupyy-molodoy-na-meli&#x27; /&#x3E;</pre>
  <img src="https://user-images.githubusercontent.com/9773803/53292083-933b6280-37bd-11e9-8762-3a47b0a3bba3.png">
</div>

<br />
<br />

<div align="center">
  <pre>&#x3C;Embed url=&#x27;https://twitter.com/hercuppacoffee/status/911958476678561792&#x27; /&#x3E;</pre>
  <img src="https://user-images.githubusercontent.com/9773803/53292170-e6fa7b80-37be-11e9-87ab-8b16ab696412.png">
</div>

<br />
<br />

<div align="center">
  <h2>
    Dark mode
  </h2>
</div>

<div align="center">
  <pre>&#x3C;Embed isDark url=&#x27;https://twitter.com/hercuppacoffee/status/911958476678561792&#x27; /&#x3E;</pre>
  <img src="https://user-images.githubusercontent.com/9773803/80277289-44a19500-86ee-11ea-8dc7-0d12888cbc2d.png">
</div>

<div align="center">
  <h2>
    Responsive
  </h2>
</div>

<div align="center">
  <pre>&#x3C;Embed url=&#x27;...&#x27; /&#x3E;</pre>
  <img src="https://user-images.githubusercontent.com/9773803/80277360-b548b180-86ee-11ea-9b25-3eaa10027ca6.png">
</div>

<div align="center">
  <pre>&#x3C;Embed width={300} url=&#x27;...&#x27; /&#x3E;</pre>
  <img src="https://user-images.githubusercontent.com/9773803/80277561-1cb33100-86f0-11ea-9d5c-bc2f55929a1d.png">
</div>

<br />
<br />

<div align="center">
  <h2>
    Supported
  </h2>
</div>

<br />

<div align="center">
  <div>DailyMotion</div>
  <div>Facebook Video</div>
  <div>Figma</div>
  <div>Gfycat</div>
  <div>Gist</div>
  <div>Google Maps</div>
  <div>imgur</div>
  <div>Instagram</div>
  <div>JSFiddle</div>
  <div>MixCloud</div>
  <div>Replit</div>
  <div>SoundCloud</div>
  <div>Twitch Channel</div>
  <div>Twitch Video</div>
  <div>Twitter Tweet</div>
  <div>Vimeo</div>
  <div>YouTube</div>
  <div>Audio files: <code>.mp3</code>, <code>.wav</code>, <code>.weba</code>, <code>.aac</code>, <code>.oga</code>, <code>.m4a</code>, <code>.mp4</code>, <code>.ogg</code>, <code>.opus</code>, <code>.ts</code>, <code>.wma</code>, <code>.mp4a</code>, <code>.mpga</code>, <code>.mp2</code>, <code>.mp2a</code>, <code>.m2a</code>, <code>.m3a</code></div>
  <div>Video files: <code>.spx</code>, <code>.mp4</code>, <code>.og</code>, <code>.ogv</code>, <code>.webm</code>, <code>.mov</code>, <code>.m4v</code>, <code>.m3u8</code>, <code>.mpd</code></div>
</div>
